JsModuleBytecode class sealed

Serialized QuickJS bytecode for a single ES module.

The name must match the module name embedded in the bytecode when it is declared or evaluated. Bytecode must be treated as trusted input and recompiled whenever the embedded QuickJS engine version changes.

Available extensions
Annotations
  • @freezed

Constructors

JsModuleBytecode({required String name, required List<int> bytes})
Creates a new module bytecode container.
factory
JsModuleBytecode.raw({required String name, required Uint8List bytes})
const
factory

Properties

bytes Uint8List
no setterinherited
copyWith → $JsModuleBytecodeCopyWith<JsModuleBytecode>
Create a copy of JsModuleBytecode with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult raw(_JsModuleBytecode value)}) → TResult

Available on JsModuleBytecode, provided by the JsModuleBytecodePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? raw(_JsModuleBytecode value)?}) → TResult?

Available on JsModuleBytecode, provided by the JsModuleBytecodePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult raw(_JsModuleBytecode value)?, required TResult orElse()}) → TResult

Available on JsModuleBytecode, provided by the JsModuleBytecodePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult raw(String name, Uint8List bytes)?, required TResult orElse()}) → TResult

Available on JsModuleBytecode, provided by the JsModuleBytecodePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult raw(String name, Uint8List bytes)}) → TResult

Available on JsModuleBytecode, provided by the JsModuleBytecodePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? raw(String name, Uint8List bytes)?}) → TResult?

Available on JsModuleBytecode, provided by the JsModuleBytecodePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited